<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Destination;

use Drupal\Component\Plugin\ConfigurableInterface;
use Drupal\Core\Plugin\PluginFormInterface;
use Drupal\Core\Plugin\PluginWithFormsInterface;
use Drupal\data_pipelines\Entity\DatasetInterface;
use Drupal\data_pipelines\Entity\DestinationInterface;

/**
 * Provides an interface for dataset destination plugins.
 */
interface DatasetDestinationPluginInterface extends PluginFormInterface, ConfigurableInterface, PluginWithFormsInterface {

  /**
   * Gets the destination label.
   *
   * @return string
   *   The label.
   */
  public function getLabel(): string;

  /**
   * Gets the destination description.
   *
   * @return string
   *   The description.
   */
  public function getDescription(): string;

  /**
   * View the destination settings.
   *
   * @return array
   *   A render array for viewing settings.
   */
  public function viewSettings(): array;

  /**
   * Saves a data set to the destination.
   *
   * @param \Drupal\data_pipelines\Entity\DatasetInterface $dataset
   *   The dataset.
   * @param \Drupal\data_pipelines\Entity\DestinationInterface $destination
   *   The destination.
   *
   * @return bool
   *   TRUE if the save succeeded.
   */
  public function saveDataSet(DatasetInterface $dataset, DestinationInterface $destination): bool;

  /**
   * Deletes a data set from the destination.
   *
   * @param \Drupal\data_pipelines\Entity\DatasetInterface $dataset
   *   The dataset.
   * @param \Drupal\data_pipelines\Entity\DestinationInterface $destination
   *   The destination.
   *
   * @return bool
   *   TRUE if the deletion succeeded.
   */
  public function deleteDataSet(DatasetInterface $dataset, DestinationInterface $destination): bool;

}
