<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Destination;

/**
 * Defines a value object for a destination request.
 */
abstract class DestinationRequest {

  /**
   * The machine name.
   *
   * @var string
   */
  protected $machineName;

  /**
   * Label to delete.
   *
   * @var string
   */
  protected $label;

  /**
   * Constructs a new DestinationRequest.
   *
   * @param string $machine_name
   *   UUID.
   * @param string $label
   *   Label.
   */
  public function __construct(string $machine_name, string $label) {
    $this->machineName = $machine_name;
    $this->label = $label;
  }

  /**
   * Gets value of machine name.
   *
   * @return string
   *   Value of machine name.
   */
  public function getMachineName(): string {
    return $this->machineName;
  }

  /**
   * Gets value of Label.
   *
   * @return string
   *   Value of Label.
   */
  public function getLabel(): string {
    return $this->label;
  }

}
