<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\EntityHandlers;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\Sql\SqlContentEntityStorage;
use Drupal\data_pipelines\Destination\DestinationSaveRequest;
use Drupal\data_pipelines\Entity\DatasetInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a storage handler for Dataset entities.
 */
class DatasetStorage extends SqlContentEntityStorage {

  /**
   * Queue factory.
   *
   * @var \Drupal\Core\Queue\QueueFactory
   */
  protected $queue;

  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    $instance = parent::createInstance($container, $entity_type);
    $instance->queue = $container->get('queue');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function delete(array $entities) {
    /** @var \Drupal\data_pipelines\Entity\DatasetInterface $dataset */
    foreach ($entities as $dataset) {
      foreach ($dataset->getDestinations() as $destination) {
        $destination->getDestinationPlugin()->deleteDataSet($dataset, $destination);
      }
    }
    parent::delete($entities);
  }

  /**
   * {@inheritdoc}
   */
  public function save(EntityInterface $entity) {
    $result = parent::save($entity);
    assert($entity instanceof DatasetInterface);
    if ($entity->isSyncing()) {
      return $result;
    }
    $queue = $this->queue->get(DatasetInterface::QUEUE_NAME_PREFIX . $entity->id());
    // Clear any previous operations.
    $queue->deleteQueue();
    $queue->createItem(new DestinationSaveRequest($entity->getMachineName(), $entity->label()));
    return $result;
  }

}
