<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Plugin\DatasetDestination;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Form\FormStateInterface;
use Drupal\data_pipelines\Entity\DatasetInterface;

/**
 * A class for providing JSON as an output.
 *
 * @DatasetDestination(
 *   id="file_json",
 *   label="JSON File",
 *   description="Writes the dataset to a JSON file"
 * )
 */
class JsonDestination extends FileDestinationBase {

  /**
   * {@inheritdoc}
   */
  protected function getFileExtension(): string {
    return 'json';
  }

  /**
   * {@inheritdoc}
   */
  protected function serializeDataset(DatasetInterface $dataset): string {
    return Json::encode(iterator_to_array($dataset->data()));
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);
    $form['dir']['#placeholder'] = 'example/';
    return $form;
  }

}
